#include <stdio.h>
#include <local/menu3.h>

static MENU MM1 = {
	0x40,
	0,
	"Web site URL",
	111,
	55,
	21,
	350,
	55,
	0,
	0,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM2 = {
	0x40,
	698,
	"cut and paste",
	48,
	55,
	55,
	350,
	90,
	0,
	0,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM3 = {
	0x4,
	55,
	NULL,
	111,
	55,
	21,
	350,
	90,
	0,
	0,
	0,
	0,
	0,
	NULL,
	&MM1,
	&MM2,
	NULL,
	NULL,
};
static MENU MM4 = {
	0x40,
	0,
	"saving state",
	116,
	55,
	90,
	350,
	125,
	0,
	0,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM5 = {
	0x40,
	0,
	"in source",
	65,
	316,
	125,
	588,
	159,
	0,
	0,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM6 = {
	0x40,
	912,
	"by name",
	66,
	316,
	159,
	588,
	194,
	0,
	0,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM7 = {
	0x4,
	159,
	NULL,
	65,
	316,
	125,
	588,
	194,
	0,
	0,
	0,
	0,
	0,
	NULL,
	&MM5,
	&MM6,
	NULL,
	NULL,
};
static MENU MM8 = {
	0x40,
	839,
	"conditional",
	100,
	316,
	194,
	588,
	229,
	0,
	0,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM9 = {
	0x40,
	0,
	"saving breakpoints",
	117,
	316,
	229,
	588,
	264,
	0,
	0,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM10 = {
	0x40,
	0,
	"C++ syntax",
	67,
	316,
	264,
	588,
	299,
	0,
	0,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM11 = {
	0x4,
	264,
	NULL,
	117,
	316,
	229,
	588,
	299,
	0,
	0,
	0,
	0,
	0,
	NULL,
	&MM9,
	&MM10,
	NULL,
	NULL,
};
static MENU MM12 = {
	0x4,
	229,
	NULL,
	100,
	316,
	194,
	588,
	299,
	0,
	0,
	0,
	0,
	0,
	NULL,
	&MM8,
	&MM11,
	NULL,
	NULL,
};
static MENU MM13 = {
	0x4,
	194,
	NULL,
	65,
	316,
	125,
	588,
	299,
	0,
	0,
	0,
	0,
	0,
	NULL,
	&MM7,
	&MM12,
	NULL,
	NULL,
};
static MENU MM14 = {
	0x40,
	802,
	"auto completion",
	68,
	316,
	299,
	588,
	333,
	0,
	0,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM15 = {
	0x40,
	767,
	"listing matches",
	69,
	316,
	333,
	588,
	368,
	0,
	0,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM16 = {
	0x4,
	333,
	NULL,
	68,
	316,
	299,
	588,
	368,
	0,
	0,
	0,
	0,
	0,
	NULL,
	&MM14,
	&MM15,
	NULL,
	NULL,
};
static MENU MM17 = {
	0x1040,
	663,
	"activation",
	70,
	316,
	368,
	588,
	403,
	0,
	0,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM18 = {
	0x40,
	0,
	"execute",
	71,
	316,
	403,
	588,
	438,
	-15992,
	29285,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM19 = {
	0x40,
	0,
	"duplicates",
	72,
	316,
	438,
	588,
	473,
	0,
	0,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM20 = {
	0x4,
	438,
	NULL,
	71,
	316,
	403,
	588,
	473,
	-21,
	-11,
	0,
	0,
	0,
	NULL,
	&MM18,
	&MM19,
	NULL,
	NULL,
};
static MENU MM21 = {
	0x4,
	403,
	NULL,
	70,
	316,
	368,
	588,
	473,
	0,
	0,
	0,
	0,
	0,
	NULL,
	&MM17,
	&MM20,
	NULL,
	NULL,
};
static MENU MM22 = {
	0x4,
	368,
	NULL,
	68,
	316,
	299,
	588,
	473,
	0,
	0,
	0,
	0,
	0,
	NULL,
	&MM16,
	&MM21,
	NULL,
	NULL,
};
static MENU MM23 = {
	0x404,
	299,
	NULL,
	0,
	316,
	125,
	588,
	473,
	0,
	0,
	0,
	0,
	0,
	NULL,
	&MM13,
	&MM22,
	NULL,
	NULL,
};
static MENU MM24 = {
	0x260,
	0,
	"breakpoints",
	49,
	55,
	125,
	350,
	159,
	0,
	0,
	0,
	0,
	0,
	NULL,
	&MM23,
	NULL,
	NULL,
	NULL,
};
static MENU MM25 = {
	0x4,
	125,
	NULL,
	116,
	55,
	90,
	350,
	159,
	0,
	0,
	0,
	0,
	0,
	NULL,
	&MM4,
	&MM24,
	NULL,
	NULL,
};
static MENU MM26 = {
	0x4,
	90,
	NULL,
	111,
	55,
	21,
	350,
	159,
	0,
	0,
	0,
	0,
	0,
	NULL,
	&MM3,
	&MM25,
	NULL,
	NULL,
};
static MENU MM27 = {
	0x40,
	0,
	"accelerators",
	50,
	55,
	159,
	350,
	194,
	0,
	0,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM28 = {
	0x40,
	98,
	"typing shortcuts",
	112,
	55,
	194,
	350,
	229,
	-15992,
	0,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM29 = {
	0x4,
	194,
	NULL,
	50,
	55,
	159,
	350,
	229,
	0,
	0,
	0,
	0,
	0,
	NULL,
	&MM27,
	&MM28,
	NULL,
	NULL,
};
static MENU MM30 = {
	0x40,
	0,
	"general",
	73,
	319,
	229,
	589,
	263,
	0,
	0,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM31 = {
	0x40,
	274,
	"step button",
	74,
	319,
	263,
	589,
	298,
	-87,
	-13,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM32 = {
	0x40,
	0,
	"casting",
	75,
	319,
	298,
	589,
	332,
	0,
	0,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM33 = {
	0x4,
	298,
	NULL,
	74,
	319,
	263,
	589,
	332,
	0,
	0,
	0,
	0,
	0,
	NULL,
	&MM31,
	&MM32,
	NULL,
	NULL,
};
static MENU MM34 = {
	0x4,
	263,
	NULL,
	73,
	319,
	229,
	589,
	332,
	0,
	0,
	0,
	0,
	0,
	NULL,
	&MM30,
	&MM33,
	NULL,
	NULL,
};
static MENU MM35 = {
	0x40,
	114,
	"tags",
	76,
	319,
	332,
	589,
	367,
	0,
	0,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM36 = {
	0x40,
	0,
	"base classes",
	110,
	319,
	367,
	589,
	401,
	0,
	0,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM37 = {
	0x4,
	367,
	NULL,
	76,
	319,
	332,
	589,
	401,
	0,
	0,
	0,
	0,
	0,
	NULL,
	&MM35,
	&MM36,
	NULL,
	NULL,
};
static MENU MM38 = {
	0x40,
	0,
	"breakpoint code",
	77,
	319,
	401,
	589,
	436,
	0,
	0,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM39 = {
	0x40,
	49,
	"RWC Strings",
	78,
	319,
	436,
	589,
	471,
	0,
	-13,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM40 = {
	0x4,
	436,
	NULL,
	77,
	319,
	401,
	589,
	471,
	0,
	0,
	0,
	0,
	0,
	NULL,
	&MM38,
	&MM39,
	NULL,
	NULL,
};
static MENU MM41 = {
	0x4,
	401,
	NULL,
	76,
	319,
	332,
	589,
	471,
	0,
	0,
	0,
	0,
	0,
	NULL,
	&MM37,
	&MM40,
	NULL,
	NULL,
};
static MENU MM42 = {
	0x404,
	332,
	NULL,
	0,
	319,
	229,
	589,
	471,
	0,
	0,
	0,
	0,
	0,
	NULL,
	&MM34,
	&MM41,
	NULL,
	NULL,
};
static MENU MM43 = {
	0x240,
	0,
	"C++ support",
	51,
	55,
	229,
	350,
	263,
	0,
	0,
	0,
	0,
	0,
	NULL,
	&MM42,
	NULL,
	NULL,
	NULL,
};
static MENU MM44 = {
	0x40,
	0,
	"source files",
	52,
	55,
	263,
	350,
	298,
	0,
	0,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM45 = {
	0x40,
	0,
	"general",
	83,
	303,
	298,
	536,
	332,
	0,
	0,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM46 = {
	0x40,
	0,
	"pointers",
	84,
	303,
	332,
	536,
	367,
	0,
	0,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM47 = {
	0x4,
	332,
	NULL,
	83,
	303,
	298,
	536,
	367,
	0,
	0,
	0,
	0,
	0,
	NULL,
	&MM45,
	&MM46,
	NULL,
	NULL,
};
static MENU MM48 = {
	0x40,
	0,
	"arrays",
	85,
	303,
	367,
	536,
	402,
	0,
	0,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM49 = {
	0x40,
	0,
	"structures",
	86,
	303,
	402,
	536,
	436,
	0,
	0,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM50 = {
	0x4,
	402,
	NULL,
	85,
	303,
	367,
	536,
	436,
	0,
	0,
	0,
	0,
	0,
	NULL,
	&MM48,
	&MM49,
	NULL,
	NULL,
};
static MENU MM51 = {
	0x4,
	367,
	NULL,
	83,
	303,
	298,
	536,
	436,
	0,
	0,
	0,
	0,
	0,
	NULL,
	&MM47,
	&MM50,
	NULL,
	NULL,
};
static MENU MM52 = {
	0x40,
	0,
	"linked data",
	87,
	303,
	436,
	536,
	471,
	0,
	0,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM53 = {
	0x40,
	0,
	"changing values",
	88,
	303,
	471,
	536,
	506,
	0,
	0,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM54 = {
	0x4,
	471,
	NULL,
	87,
	303,
	436,
	536,
	506,
	0,
	0,
	0,
	0,
	0,
	NULL,
	&MM52,
	&MM53,
	NULL,
	NULL,
};
static MENU MM55 = {
	0x40,
	0,
	"typedefs",
	89,
	303,
	506,
	536,
	540,
	0,
	0,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM56 = {
	0x40,
	0,
	"expressions",
	90,
	303,
	540,
	536,
	575,
	0,
	0,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM57 = {
	0x40,
	0,
	"dump memory",
	97,
	303,
	575,
	536,
	610,
	0,
	0,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM58 = {
	0x4,
	575,
	NULL,
	90,
	303,
	540,
	536,
	610,
	0,
	0,
	0,
	0,
	0,
	NULL,
	&MM56,
	&MM57,
	NULL,
	NULL,
};
static MENU MM59 = {
	0x4,
	540,
	NULL,
	89,
	303,
	506,
	536,
	610,
	0,
	0,
	0,
	0,
	0,
	NULL,
	&MM55,
	&MM58,
	NULL,
	NULL,
};
static MENU MM60 = {
	0x4,
	506,
	NULL,
	87,
	303,
	436,
	536,
	610,
	0,
	0,
	0,
	0,
	0,
	NULL,
	&MM54,
	&MM59,
	NULL,
	NULL,
};
static MENU MM61 = {
	0x404,
	436,
	NULL,
	0,
	303,
	298,
	536,
	610,
	0,
	0,
	0,
	0,
	0,
	NULL,
	&MM51,
	&MM60,
	NULL,
	NULL,
};
static MENU MM62 = {
	0x240,
	0,
	"examing data",
	53,
	55,
	298,
	350,
	333,
	0,
	0,
	0,
	0,
	0,
	NULL,
	&MM61,
	NULL,
	NULL,
	NULL,
};
static MENU MM63 = {
	0x4,
	298,
	NULL,
	52,
	55,
	263,
	350,
	333,
	0,
	0,
	0,
	0,
	0,
	NULL,
	&MM44,
	&MM62,
	NULL,
	NULL,
};
static MENU MM64 = {
	0x4,
	263,
	NULL,
	51,
	55,
	229,
	350,
	333,
	0,
	0,
	0,
	0,
	0,
	NULL,
	&MM43,
	&MM63,
	NULL,
	NULL,
};
static MENU MM65 = {
	0x4,
	229,
	NULL,
	50,
	55,
	159,
	350,
	333,
	0,
	0,
	0,
	0,
	0,
	NULL,
	&MM29,
	&MM64,
	NULL,
	NULL,
};
static MENU MM66 = {
	0x4,
	159,
	NULL,
	111,
	55,
	21,
	350,
	333,
	0,
	0,
	0,
	0,
	0,
	NULL,
	&MM26,
	&MM65,
	NULL,
	NULL,
};
static MENU MM67 = {
	0x40,
	0,
	"editable fields",
	54,
	55,
	333,
	350,
	367,
	0,
	0,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM68 = {
	0x40,
	0,
	"command arguments",
	55,
	55,
	367,
	350,
	402,
	0,
	0,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM69 = {
	0x4,
	367,
	NULL,
	54,
	55,
	333,
	350,
	402,
	0,
	0,
	0,
	0,
	0,
	NULL,
	&MM67,
	&MM68,
	NULL,
	NULL,
};
static MENU MM70 = {
	0x40,
	0,
	"custom menu",
	56,
	55,
	402,
	350,
	437,
	0,
	0,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM71 = {
	0x40,
	0,
	"init file",
	57,
	55,
	437,
	350,
	471,
	0,
	0,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM72 = {
	0x4,
	437,
	NULL,
	56,
	55,
	402,
	350,
	471,
	0,
	0,
	0,
	0,
	0,
	NULL,
	&MM70,
	&MM71,
	NULL,
	NULL,
};
static MENU MM73 = {
	0x4,
	402,
	NULL,
	54,
	55,
	333,
	350,
	471,
	0,
	0,
	0,
	0,
	0,
	NULL,
	&MM69,
	&MM72,
	NULL,
	NULL,
};
static MENU MM74 = {
	0x40,
	0,
	"attach / detach",
	33,
	55,
	471,
	350,
	506,
	0,
	0,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM75 = {
	0x40,
	0,
	"resizing windows",
	103,
	55,
	506,
	350,
	541,
	0,
	0,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM76 = {
	0x4,
	506,
	NULL,
	33,
	55,
	471,
	350,
	541,
	0,
	0,
	0,
	0,
	0,
	NULL,
	&MM74,
	&MM75,
	NULL,
	NULL,
};
static MENU MM77 = {
	0x40,
	0,
	"signals",
	104,
	55,
	541,
	350,
	575,
	0,
	0,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM78 = {
	0x40,
	0,
	"ups version",
	118,
	312,
	575,
	558,
	611,
	0,
	0,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM79 = {
	0x40,
	0,
	"`step' action",
	115,
	312,
	611,
	558,
	647,
	0,
	0,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM80 = {
	0x4,
	611,
	NULL,
	118,
	312,
	575,
	558,
	647,
	0,
	0,
	0,
	0,
	0,
	NULL,
	&MM78,
	&MM79,
	NULL,
	NULL,
};
static MENU MM81 = {
	0x40,
	0,
	"scrollbars",
	79,
	312,
	647,
	558,
	684,
	0,
	0,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM82 = {
	0x40,
	0,
	"assembler",
	80,
	312,
	684,
	558,
	720,
	0,
	0,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM83 = {
	0x40,
	0,
	"authors",
	81,
	312,
	720,
	558,
	757,
	0,
	0,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM84 = {
	0x4,
	720,
	NULL,
	80,
	312,
	684,
	558,
	757,
	0,
	0,
	0,
	0,
	0,
	NULL,
	&MM82,
	&MM83,
	NULL,
	NULL,
};
static MENU MM85 = {
	0x4,
	684,
	NULL,
	79,
	312,
	647,
	558,
	757,
	0,
	0,
	0,
	0,
	0,
	NULL,
	&MM81,
	&MM84,
	NULL,
	NULL,
};
static MENU MM86 = {
	0x404,
	647,
	NULL,
	0,
	312,
	575,
	558,
	757,
	0,
	0,
	0,
	0,
	0,
	NULL,
	&MM80,
	&MM85,
	NULL,
	NULL,
};
static MENU MM87 = {
	0x240,
	0,
	"miscellaneous",
	105,
	55,
	575,
	350,
	610,
	0,
	0,
	0,
	0,
	0,
	NULL,
	&MM86,
	NULL,
	NULL,
	NULL,
};
static MENU MM88 = {
	0x40,
	0,
	"append text",
	108,
	309,
	611,
	582,
	645,
	0,
	0,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM89 = {
	0x40,
	0,
	"always clear",
	109,
	309,
	645,
	582,
	680,
	0,
	0,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM90 = {
	0x404,
	645,
	NULL,
	0,
	309,
	611,
	582,
	680,
	0,
	0,
	0,
	0,
	0,
	NULL,
	&MM88,
	&MM89,
	NULL,
	NULL,
};
static MENU MM91 = {
	0x240,
	0,
	"help window",
	106,
	55,
	610,
	350,
	645,
	0,
	0,
	0,
	0,
	0,
	NULL,
	&MM90,
	NULL,
	NULL,
	NULL,
};
static MENU MM92 = {
	0x4,
	610,
	NULL,
	105,
	55,
	575,
	350,
	645,
	0,
	0,
	0,
	0,
	0,
	NULL,
	&MM87,
	&MM91,
	NULL,
	NULL,
};
static MENU MM93 = {
	0x4,
	575,
	NULL,
	104,
	55,
	541,
	350,
	645,
	0,
	0,
	0,
	0,
	0,
	NULL,
	&MM77,
	&MM92,
	NULL,
	NULL,
};
static MENU MM94 = {
	0x4,
	541,
	NULL,
	33,
	55,
	471,
	350,
	645,
	0,
	0,
	0,
	0,
	0,
	NULL,
	&MM76,
	&MM93,
	NULL,
	NULL,
};
static MENU MM95 = {
	0x4,
	471,
	NULL,
	54,
	55,
	333,
	350,
	645,
	0,
	0,
	0,
	0,
	0,
	NULL,
	&MM73,
	&MM94,
	NULL,
	NULL,
};
static MENU MM96 = {
	0x404,
	333,
	NULL,
	0,
	55,
	21,
	350,
	645,
	-21,
	-11,
	0,
	0,
	0,
	NULL,
	&MM66,
	&MM95,
	NULL,
	NULL,
};
static MENU MM97 = {
	0x2260,
	0,
	"Help",
	101,
	-1,
	-1,
	76,
	32,
	0,
	0,
	0,
	0,
	0,
	NULL,
	&MM96,
	NULL,
	NULL,
	NULL,
};
static MENU MM98 = {
	0x40,
	0,
	"Backwards",
	98,
	2,
	0,
	134,
	35,
	0,
	0,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM99 = {
	0x40,
	0,
	"Forwards",
	102,
	134,
	0,
	291,
	35,
	0,
	0,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM100 = {
	0x408,
	134,
	NULL,
	0,
	2,
	0,
	291,
	35,
	0,
	0,
	0,
	0,
	0,
	NULL,
	&MM98,
	&MM99,
	NULL,
	NULL,
};
static MENU MM101 = {
	0x260,
	0,
	"Search",
	122,
	76,
	-1,
	194,
	32,
	0,
	0,
	0,
	0,
	0,
	NULL,
	&MM100,
	NULL,
	NULL,
	NULL,
};
static MENU MM102 = {
	0x8,
	76,
	NULL,
	101,
	-1,
	-1,
	194,
	32,
	0,
	0,
	0,
	0,
	0,
	NULL,
	&MM97,
	&MM101,
	NULL,
	NULL,
};
static MENU MM103 = {
	0x40,
	0,
	"Selected object",
	99,
	249,
	19,
	551,
	50,
	0,
	0,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM104 = {
	0x40,
	0,
	"All objects",
	119,
	249,
	50,
	551,
	82,
	0,
	0,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM105 = {
	0x4,
	50,
	NULL,
	99,
	249,
	19,
	551,
	82,
	0,
	0,
	0,
	0,
	0,
	NULL,
	&MM103,
	&MM104,
	NULL,
	NULL,
};
static MENU MM106 = {
	0x40,
	0,
	"msg logging on",
	120,
	249,
	82,
	551,
	114,
	0,
	0,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM107 = {
	0x40,
	0,
	"msg logging off",
	121,
	249,
	114,
	551,
	147,
	0,
	0,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM108 = {
	0x4,
	114,
	NULL,
	120,
	249,
	82,
	551,
	147,
	0,
	0,
	0,
	0,
	0,
	NULL,
	&MM106,
	&MM107,
	NULL,
	NULL,
};
static MENU MM109 = {
	0x404,
	82,
	NULL,
	0,
	249,
	19,
	551,
	147,
	-87,
	-13,
	0,
	0,
	0,
	NULL,
	&MM105,
	&MM108,
	NULL,
	NULL,
};
static MENU MM110 = {
	0x2260,
	0,
	"Snapshot",
	98,
	194,
	-1,
	336,
	32,
	0,
	0,
	0,
	0,
	0,
	NULL,
	&MM109,
	NULL,
	NULL,
	NULL,
};
static MENU MM111 = {
	0x40,
	0,
	"cancel",
	63,
	415,
	19,
	574,
	49,
	0,
	0,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM112 = {
	0x40,
	0,
	"confirm",
	113,
	415,
	49,
	574,
	80,
	0,
	0,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
static MENU MM113 = {
	0x404,
	49,
	NULL,
	0,
	415,
	19,
	574,
	80,
	0,
	-13,
	0,
	0,
	0,
	NULL,
	&MM111,
	&MM112,
	NULL,
	NULL,
};
static MENU MM114 = {
	0x2260,
	0,
	"Quit",
	97,
	336,
	-1,
	415,
	32,
	0,
	0,
	0,
	0,
	0,
	NULL,
	&MM113,
	NULL,
	NULL,
	NULL,
};
static MENU MM115 = {
	0x8,
	336,
	NULL,
	98,
	194,
	-1,
	415,
	32,
	0,
	0,
	0,
	0,
	0,
	NULL,
	&MM110,
	&MM114,
	NULL,
	NULL,
};
MENU cmd_men = {
	0x408,
	194,
	NULL,
	0,
	-1,
	-1,
	415,
	32,
	0,
	0,
	0,
	0,
	0,
	NULL,
	&MM102,
	&MM115,
	NULL,
	NULL,
};
